library("testthat", exclude = "matches")
library("ItemResponseTrees")

test_check("ItemResponseTrees")
